# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cisco_otel_py',
 'cisco_otel_py.cmd',
 'cisco_otel_py.instrumentations',
 'cisco_otel_py.instrumentations.requests']

package_data = \
{'': ['*']}

install_requires = \
['Flask>=2.0.3,<3.0.0',
 'argparse>=1.4.0,<2.0.0',
 'cisco-opentelemetry-specifications>=0.0.4,<0.0.5',
 'opentelemetry-exporter-otlp==1.7.1',
 'opentelemetry-instrumentation-requests==0.26b1',
 'opentelemetry-instrumentation==0.26b1',
 'opentelemetry-sdk==1.7.1',
 'pytest-cov>=3.0.0,<4.0.0',
 'requests>=2.27.1,<3.0.0',
 'virtualenv>=20.13.3,<21.0.0']

entry_points = \
{'console_scripts': ['otel-py = cisco_otel_py.cmd.trace:run',
                     'otel-py-bootstrap = cisco_otel_py.cmd.bootstrap:run']}

setup_kwargs = {
    'name': 'cisco-otel-py',
    'version': '0.1.11',
    'description': 'a minimal python Cisco Launcher for OpenTelemetry',
    'long_description': '# otel-py\n\nAlpha version\nThis package provides a Cisco Launcher for OpenTelemetry python\n\n## Installation\n\npip\n\n```sh\npip install cisco-otel-py\n```\n\npoetry\n\n```sh\npoetry add cisco-otel-py\n```\n\n## Usage\n\nOne-time script run to install opentelemetry dependencies:\n\n```shell\notel-py-bootstrap\n```\n\n```python\nfrom cisco_otel_py import tracing, options\n\ntracing.init(\n    service_name="my-service-name",\n    cisco_token="my-cisco-token",\n    exporters=[options.ExporterOptions(\n        collector_endpoint="http://localhost:4317",\n        exporter_type="otlp-grpc"\n    )]\n)\n```\n\n## Configuration\n\nAdvanced options can be configured as a parameter to the init() method:\n\n| Parameter          | Env                     | Type    | Default                 | Description                                                       |\n| ------------------ | ------------------------| ------- | ----------------------- | ----------------------------------------------------------------- |\n| cisco_token        | CISCO_TOKEN             | string  | -                       | Cisco account token                                               |\n| service_name       | OTEL_SERVICE_NAME       | string  | `application`           | Application name that will be set for traces                      |\n| collector_endpoint | OTEL_COLLECTOR_ENDPOINT | string  | `http://localhost:4317` | The address of the trace collector to send traces to                                                                                                |\n| type               | OTEL_EXPORTER_TYPE      | string  | `otlp-grpc`             | The exporter type to use (Currently `otlp-grpc`, `otlp-http` are supported). Multiple exporter option available via init function see example below |\n\nExporter options\n| Parameter          | Env                     | Type   | Default                 | Description                              |\n| ------------------ |------------------------ | ------ | ----------------------- | ---------------------------------------- |\n| collector_endpoint | OTEL_COLLECTOR_ENDPOINT | string | `http://localhost:4317` | The address of the trace collector to send traces to|\n| exporter_type      | OTEL_EXPORTER_TYPE      | string | `otlp-grpc`             | The exporter type to use (Currently `otlp-grpc`, `otlp-http` are supported). Multiple exporter option available via init function see example bellow|\n\n## Multi-exporter initiation\n\n```python\nfrom cisco_otel_py import tracing, options\n\ntracing.init(\n    service_name="my-service-name",\n    cisco_token="my-cisco-token",\n    exporters=[\n        options.ExporterOptions(\n            collector_endpoint="http://localhost:4317",\n            exporter_type="otlp-grpc"),\n        options.ExporterOptions(\n            collector_endpoint="remote-http-collector-endpoint",\n            exporter_type="otlp-http"\n        )]\n)\n```',
    'author': 'Cisco Epsagon Team',
    'author_email': 'support@epsagon.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/epsagon/otel-py',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
